@@ -141,6 +141,7 @@ class Broker:
             self._ON_CHANNEL_OPEN,
             callback,
             one_shot,
+            False,
             *args,
             **kwargs
         )
@@ -150,6 +151,7 @@ class Broker:
             self._ON_CONNECTION_OPEN,
             callback,
             one_shot,
+            False,
             *args,
             **kwargs
         )
@@ -194,12 +196,10 @@ class Broker:
     async def __until_connected(self):
         if self.__channel is None or self.__connection is None:
             await asyncio.sleep(0.1)
-            print("test")
         else:
             if self.__channel.is_open and self.__connection.is_open:
                 return
             else:
-                print("test")
                 self.__loop.call_later(
                     0.1,
                     self.__until_connected
